@@ -26,7 +26,8 @@ from .cross import PY3
 if PY3:
     _zip = zip
     def zip(*seqs):
+        """List zip() version."""
         return list(_zip(*seqs))
-    __all__.append('zip')
+    __all__ += ['zip']  # HACK: using this instead of .append() to not trigger PyCharm
 else:
     zip = zip
